root_doc = 'equations'
extensions = ['sphinx.ext.imgmath']
